# Azure Functions Extension Base library for Python
This is the base library for allowing Python Function Apps to recognize and bind to SDk-types and HttpV2-types. It is not to be used directly.
Instead, please reference one of the extending packages:
* azurefunctions-extensions-blob
* azurefunctions-extensions-fastapi
